@@ -25,7 +25,9 @@ class MainApplication(tk.Frame):
         self.text = Text()
         self.dark = tk.BooleanVar()
         self.dark.set(False)
-        self.DoseFigureHandler = DoseFigureHandler(self)
+        self.norm = tk.BooleanVar()
+        self.norm.set(bool(self.profile.get_attribute("normalize")))
+        self.DoseFigureHandler = DoseFigureHandler(self, self.norm.get())
 
         self.parent.title(self.text.window_title[self.lang])
         style = ttk.Style(self.parent)
@@ -153,6 +155,49 @@ class MainApplication(tk.Frame):
         self.menubar.add_cascade(
             label=self.text.options[self.lang], menu=self.optionsmenu
         )
+
+        self.normmenu = tk.Menu(self.menubar)
+        self.normmenu.add_checkbutton(
+            label=self.text.normalize[self.lang],
+            command=lambda: self.normalize(self.norm.get()),
+            variable=self.norm,
+        )
+        self.normmenu.add_separator()
+        self.markersizemenu = tk.Menu(self.menubar)
+        self.markersizemenu.add_command(
+            label=Text().increase[self.lang],
+            command=lambda: self.change_marker_size(True),
+            accelerator="Ctrl + ↑",
+        )
+        self.parent.bind("<Control-Up>", self.up_down_key)
+        self.markersizemenu.add_command(
+            label=Text().decrease[self.lang],
+            command=lambda: self.change_marker_size(False),
+            accelerator="Ctrl + ↓",
+        )
+        self.parent.bind("<Control-Down>", self.up_down_key)
+
+        self.markerlinemenu = tk.Menu(self.menubar)
+        self.markerlinemenu.add_command(
+            label=Text().increase[self.lang],
+            command=lambda: self.change_line_width(True),
+            accelerator="Ctrl + →",
+        )
+        self.parent.bind("<Control-Right>", self.right_left_key)
+        self.markerlinemenu.add_command(
+            label=Text().decrease[self.lang],
+            command=lambda: self.change_line_width(False),
+            accelerator="Ctrl + ←",
+        )
+        self.parent.bind("<Control-Left>", self.right_left_key)
+
+        self.normmenu.add_cascade(
+            label=Text().markerline[self.lang], menu=self.markerlinemenu
+        )
+        self.normmenu.add_cascade(
+            label=Text().marker[self.lang], menu=self.markersizemenu
+        )
+
         self.parent.config(menu=self.menubar)
 
         # Initialize necessary variables
@@ -225,6 +270,51 @@ class MainApplication(tk.Frame):
         self.__init__(self.parent, geometry)
         return
 
+    def normalize(self, norm):
+
+        self.DoseFigureHandler.norm = self.norm.get()
+
+        self.profile.set_attribute("normalize", int(self.norm.get()))
+
+        if self.filenames != []:
+            self.canvas.itemconfig(self.image_on_canvas, image=None)
+            self.DoseFigureHandler.flush()
+            self.show_preview()
+        return
+
+    def change_marker_size(self, boolean):
+        if boolean == True:
+            self.DoseFigureHandler.markersize += 0.2
+        else:
+            self.DoseFigureHandler.markersize -= 0.2
+
+        if self.DoseFigureHandler.markersize < 0:
+            self.DoseFigureHandler.markersize = 0
+
+        self.profile.set_attribute("markersize", self.DoseFigureHandler.markersize)
+
+        if self.filenames != []:
+            self.canvas.itemconfig(self.image_on_canvas, image=None)
+            self.DoseFigureHandler.flush()
+            self.show_preview()
+        return
+
+    def change_line_width(self, boolean):
+        if boolean == True:
+            self.DoseFigureHandler.linewidth += 0.2
+        else:
+            self.DoseFigureHandler.linewidth -= 0.2
+        if self.DoseFigureHandler.linewidth < 0.2:
+            self.DoseFigureHandler.linewidth = 0.2
+
+        self.profile.set_attribute("linewidth", self.DoseFigureHandler.linewidth)
+
+        if self.filenames != []:
+            self.canvas.itemconfig(self.image_on_canvas, image=None)
+            self.DoseFigureHandler.flush()
+            self.show_preview()
+        return
+
     def load_file(self, type):
 
         """
@@ -232,9 +322,9 @@ class MainApplication(tk.Frame):
         """
 
         if type == "simulation":
-            filetypes = [("Simulationsergebnisse", ".csv")]
+            filetypes = [(self.text.simulationdata[self.lang], ".csv")]
         else:
-            filetypes = [("Messdaten", ["txt", ".csv"])]
+            filetypes = [(self.text.measurementdata[self.lang], ["txt", ".csv"])]
 
         self.current_file = fd.askopenfilename(
             initialdir=os.getcwd(), filetypes=filetypes
@@ -262,11 +352,14 @@ class MainApplication(tk.Frame):
         self.filemenu.entryconfig(1, state=tk.NORMAL)
         self.filemenu.entryconfig(3, state=tk.DISABLED)
         self.filemenu.entryconfig(4, state=tk.DISABLED)
-        self.menubar.delete(3)
+        self.addmeasuremenu.entryconfig(0, state=tk.NORMAL)
+        self.addmeasuremenu.entryconfig(1, state=tk.NORMAL)
+        self.menubar.delete(3, 4)
         self.filenames = []
         self.canvas.itemconfig(self.image_on_canvas, image=None)
         self.menuflag = False
         self.DoseFigureHandler.flush()
+        self.DoseFigureHandler.plots = []
 
     def remove_last_addition(self):
 
@@ -284,6 +377,7 @@ class MainApplication(tk.Frame):
 
         self.canvas.itemconfig(self.image_on_canvas, image=None)
         self.DoseFigureHandler.flush()
+        self.DoseFigureHandler.plots.pop(-1)
         self.show_preview()
 
     def save_graph(self):
@@ -293,7 +387,8 @@ class MainApplication(tk.Frame):
         """
 
         file = fd.asksaveasfilename(
-            defaultextension=".png", filetypes=[("Bilder", [".png", ".jpg"])]
+            defaultextension=".png",
+            filetypes=[(self.text.image[self.lang], [".png", ".jpg"])],
         )
 
         if file is None:
@@ -307,7 +402,7 @@ class MainApplication(tk.Frame):
         """
         Invokes DoseFigureHandler to create and display the graphs
         """
-
+        self.DoseFigureHandler.flush()
         self.photoimage, menuflag = self.DoseFigureHandler.return_figure(self.filenames)
 
         self.canvas.pack_forget()
@@ -322,8 +417,14 @@ class MainApplication(tk.Frame):
             self.addmenu.entryconfig(0, state=tk.DISABLED)
             self.addmenu.entryconfig(1, state=tk.DISABLED)
 
-        if menuflag == "Z" and self.menuflag == False:
+        if menuflag == "Z":
+            self.addmeasuremenu.entryconfig(1, state=tk.DISABLED)
+        else:
+            self.addmeasuremenu.entryconfig(0, state=tk.DISABLED)
+
+        if self.menuflag == False:
             self.menubar.add_cascade(label=self.text.add[self.lang], menu=self.addmenu)
+            self.menubar.add_cascade(label="Graph", menu=self.normmenu)
             self.menuflag = True
         self.image_on_canvas = self.canvas.create_image(
             0, 0, anchor=tk.NW, image=self.photoimage
@@ -380,3 +481,15 @@ class MainApplication(tk.Frame):
 
     def s_key(self, event=None):
         self.save_graph()
+
+    def up_down_key(self, event=None):
+        if event.keysym == "Up":
+            self.change_marker_size(True)
+        else:
+            self.change_marker_size(False)
+
+    def right_left_key(self, event=None):
+        if event.keysym == "Right":
+            self.change_line_width(True)
+        else:
+            self.change_line_width(False)
